@@ -77,11 +77,10 @@ class PseudocodefrLexer(RegexLexer):
                    Name.Constant),
                   
                  # Operators
-                 (r'(<=|>=|<>|!=|<-|\^|\*|\+|-|\/|<|>|=|\\\\|mod|←|↑|→|≤|≥|≠|÷|×|\.\.|\[|\]|\.)',
+                 (r'(<=|>=|<>|!=|<-|\^|\*|\+|-|\/|<|>|=|\\\\|mod|←|↑|→|≤|≥|≠|÷|×|\.\.|\[|\]|\.|non|xou|et|ou)',
                   op_replace),
 
-                # Operator Words
-                (r'(non|xou|et|ou)', Operator.Word )
+
 
                  (r'(\(|\)|\,|\;|:)',
                   Punctuation),
